---
name: v.what
description: Queries a vector map at given locations.
keywords: [ vector, querying, position ]
---

# v.what

Queries a vector map at given locations.

=== "Command line"

    **v.what**
    [**-dagjm**]
    **map**=*name* [,*name*,...]
    [**layer**=*string* [,*string*,...]]
    [**type**=*string* [,*string*,...]]
    **coordinates**=*east,north*
    [**distance**=*float*]
    [**columns**=*name* [,*name*,...]]
    [**--verbose**]
    [**--quiet**]
    [**--qq**]
    [**--ui**]

    Example:

    ```sh
    v.what map=name coordinates=east,north
    ```

=== "Python (grass.script)"

    *grass.script.parse_command*("***v.what***",
        **map**,
        **layer**=*"-1"*,
        **type**=*"point,line,area,face"*,
        **coordinates**,
        **distance**=*0*,
        **columns**=*None*,
        **flags**=*None*,
        **verbose**=*False*,
        **quiet**=*False*,
        **superquiet**=*False*)

    Example:

    ```python
    gs.parse_command("v.what", map="name", coordinates=east,north)
    ```

## Parameters

=== "Command line"

    **map**=*name* [,*name*,...] **[required]**  
    &nbsp;&nbsp;&nbsp;&nbsp;Name of vector map(s)  
    **layer**=*string* [,*string*,...]  
    &nbsp;&nbsp;&nbsp;&nbsp;Layer number or name ('-1' for all layers)  
    &nbsp;&nbsp;&nbsp;&nbsp;A single vector map can be connected to multiple database tables. This number determines which table to use. When used with direct OGR access this is the layer name.  
    &nbsp;&nbsp;&nbsp;&nbsp;Default: *-1*  
    **type**=*string* [,*string*,...]  
    &nbsp;&nbsp;&nbsp;&nbsp;Input feature type  
    &nbsp;&nbsp;&nbsp;&nbsp;Allowed values: *point, line, boundary, centroid, area, face, kernel*  
    &nbsp;&nbsp;&nbsp;&nbsp;Default: *point,line,area,face*  
    **coordinates**=*east,north* **[required]**  
    &nbsp;&nbsp;&nbsp;&nbsp;Coordinates for query  
    &nbsp;&nbsp;&nbsp;&nbsp;'-' for standard input  
    **distance**=*float*  
    &nbsp;&nbsp;&nbsp;&nbsp;Query threshold distance  
    &nbsp;&nbsp;&nbsp;&nbsp;Default: *0*  
    **columns**=*name* [,*name*,...]  
    &nbsp;&nbsp;&nbsp;&nbsp;Name of attribute column(s)  
    &nbsp;&nbsp;&nbsp;&nbsp;Default: all columns  
    **-d**  
    &nbsp;&nbsp;&nbsp;&nbsp;Print topological information (debugging)  
    **-a**  
    &nbsp;&nbsp;&nbsp;&nbsp;Print attribute information  
    **-g**  
    &nbsp;&nbsp;&nbsp;&nbsp;Print the stats in shell script style  
    **-j**  
    &nbsp;&nbsp;&nbsp;&nbsp;Print the stats in JSON  
    **-m**  
    &nbsp;&nbsp;&nbsp;&nbsp;Print multiple features if overlapping features are found  
    **--help**  
    &nbsp;&nbsp;&nbsp;&nbsp;Print usage summary  
    **--verbose**  
    &nbsp;&nbsp;&nbsp;&nbsp;Verbose module output  
    **--quiet**  
    &nbsp;&nbsp;&nbsp;&nbsp;Quiet module output  
    **--qq**  
    &nbsp;&nbsp;&nbsp;&nbsp;Very quiet module output  
    **--ui**  
    &nbsp;&nbsp;&nbsp;&nbsp;Force launching GUI dialog

=== "Python (grass.script)"

    **map** : str | list[str], *required*  
    &nbsp;&nbsp;&nbsp;&nbsp;Name of vector map(s)  
    &nbsp;&nbsp;&nbsp;&nbsp;Used as: input, vector, *name*  
    **layer** : str | list[str], *optional*  
    &nbsp;&nbsp;&nbsp;&nbsp;Layer number or name ('-1' for all layers)  
    &nbsp;&nbsp;&nbsp;&nbsp;A single vector map can be connected to multiple database tables. This number determines which table to use. When used with direct OGR access this is the layer name.  
    &nbsp;&nbsp;&nbsp;&nbsp;Used as: input, layer  
    &nbsp;&nbsp;&nbsp;&nbsp;Default: *-1*  
    **type** : str | list[str], *optional*  
    &nbsp;&nbsp;&nbsp;&nbsp;Input feature type  
    &nbsp;&nbsp;&nbsp;&nbsp;Allowed values: *point, line, boundary, centroid, area, face, kernel*  
    &nbsp;&nbsp;&nbsp;&nbsp;Default: *point,line,area,face*  
    **coordinates** : tuple[float, float] | list[float] | str, *required*  
    &nbsp;&nbsp;&nbsp;&nbsp;Coordinates for query  
    &nbsp;&nbsp;&nbsp;&nbsp;'-' for standard input  
    &nbsp;&nbsp;&nbsp;&nbsp;Used as: input, coords, *east,north*  
    **distance** : float, *optional*  
    &nbsp;&nbsp;&nbsp;&nbsp;Query threshold distance  
    &nbsp;&nbsp;&nbsp;&nbsp;Default: *0*  
    **columns** : str | list[str], *optional*  
    &nbsp;&nbsp;&nbsp;&nbsp;Name of attribute column(s)  
    &nbsp;&nbsp;&nbsp;&nbsp;Default: all columns  
    &nbsp;&nbsp;&nbsp;&nbsp;Used as: input, dbcolumn, *name*  
    **flags** : str, *optional*  
    &nbsp;&nbsp;&nbsp;&nbsp;Allowed values: *d*, *a*, *g*, *j*, *m*  
    &nbsp;&nbsp;&nbsp;&nbsp;**d**  
    &nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;Print topological information (debugging)  
    &nbsp;&nbsp;&nbsp;&nbsp;**a**  
    &nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;Print attribute information  
    &nbsp;&nbsp;&nbsp;&nbsp;**g**  
    &nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;Print the stats in shell script style  
    &nbsp;&nbsp;&nbsp;&nbsp;**j**  
    &nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;Print the stats in JSON  
    &nbsp;&nbsp;&nbsp;&nbsp;**m**  
    &nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;Print multiple features if overlapping features are found  
    **verbose**: bool, *optional*  
    &nbsp;&nbsp;&nbsp;&nbsp;Verbose module output  
    &nbsp;&nbsp;&nbsp;&nbsp;Default: *False*  
    **quiet**: bool, *optional*  
    &nbsp;&nbsp;&nbsp;&nbsp;Quiet module output  
    &nbsp;&nbsp;&nbsp;&nbsp;Default: *False*  
    **superquiet**: bool, *optional*  
    &nbsp;&nbsp;&nbsp;&nbsp;Very quiet module output  
    &nbsp;&nbsp;&nbsp;&nbsp;Default: *False*

## DESCRIPTION

*v.what* outputs the category number value(s) associated with
user-specified location(s) in user-specified vector map layer(s). This
module was derived from the *d.what.vect* module by removing all
interactive code and modification of the output for easy parsing. Using
the *-g* flag generates script-style output which is easily parsable.

## EXAMPLE

North Carolina sample dataset example:

Query polygon at given position:

```sh
v.what zipcodes_wake coordinates=637502.25,221744.25
```

Find closest hospital to given position within given distance (search
radius):

```sh
v.what hospitals coordinates=542690.4,204802.7 distance=2000000
```

## SEE ALSO

*[d.what.rast](d.what.rast.md), [d.what.vect](d.what.vect.md),
[v.rast.stats](v.rast.stats.md), [v.vect.stats](v.vect.stats.md),
[v.what.rast](v.what.rast.md), [v.what.rast3](v.what.rast3.md),
[v.what.vect](v.what.vect.md)*

## AUTHOR

Trevor Wiens  
Edmonton, Alberta, Canada

## SOURCE CODE

Available at: [v.what source code](https://github.com/OSGeo/grass/tree/main/vector/v.what)
([history](https://github.com/OSGeo/grass/commits/main/vector/v.what))  
Latest change: Friday May 09 14:33:40 2025 in commit [b356c7e](https://github.com/OSGeo/grass/commit/b356c7e108fcbeca77474c8e83ebec8f1e7b3e4a)
